@@ -38,7 +38,7 @@ handler_predict.train <- function(vetiver_model, ...) {
 
     function(req) {
         newdata <- req$body
-        newdata <- vetiver_type_convert(newdata, vetiver_model$ptype)
+        newdata <- vetiver_type_convert(newdata, vetiver_model$prototype)
         predict(vetiver_model$model, newdata = newdata, ...)
     }
 
