@@ -5,7 +5,6 @@
 #' @param ... Extra arguments passed to [httr::POST()]
 #'
 #' @return A tibble of model predictions with as many rows as in `new_data`.
-#' @importFrom stats predict
 #' @seealso [augment.vetiver_endpoint()]
 #' @export
 #'
@@ -19,6 +18,7 @@
 #'
 predict.vetiver_endpoint <- function(object, new_data, ...) {
     rlang::check_installed(c("jsonlite", "httr"))
+    ellipsis::check_dots_used()
     data_json <- jsonlite::toJSON(new_data, na = "string")
     ret <- httr::POST(object$url, ..., body = data_json)
     resp <- httr::content(ret, "text", encoding = "UTF-8")
