@@ -12,11 +12,14 @@ DEFAULT_RSPM <-  "https://packagemanager.rstudio.com"
 #' [vetiver_write_plumber()]. Defaults to `plumber.R` in the working directory.
 #' @param path A path to write the Dockerfile and `lockfile`, capturing the
 #' model's package dependencies. Defaults to the working directory.
+#' @param ... Not currently used.
 #' @param lockfile The generated lockfile in `path`. Defaults to
 #' `"vetiver_renv.lock"`.
 #' @param rspm A logical to use the
 #' [RStudio Public Package Manager](https://packagemanager.rstudio.com/) for
 #' `renv::restore()` in the Docker image. Defaults to `TRUE`.
+#' @param base_image The base Docker image to start with. Defaults to
+#' `rocker/r-ver` for the version of R you are working with.
 #' @param port The server port for listening: a number such as 8080 or an
 #' expression like `'as.numeric(Sys.getenv("PORT"))'` when the port is injected
 #' as an environment variable.
@@ -52,22 +55,25 @@ DEFAULT_RSPM <-  "https://packagemanager.rstudio.com"
 vetiver_write_docker <- function(vetiver_model,
                                  plumber_file = "plumber.R",
                                  path = ".",
+                                 ...,
                                  lockfile = "vetiver_renv.lock",
                                  rspm = TRUE,
+                                 base_image = glue::glue("FROM rocker/r-ver:{getRversion()}"),
                                  port = 8000,
                                  expose = TRUE,
                                  additional_pkgs = character(0)) {
 
-    from_r_version <- glue::glue("FROM rocker/r-ver:{getRversion()}")
+    ellipsis::check_dots_empty()
+    withr::local_options(list(renv.dynamic.enabled = FALSE))
+
     rspm_env <- ifelse(
         rspm,
         "ENV RENV_CONFIG_REPOS_OVERRIDE https://packagemanager.rstudio.com/cran/latest\n",
         ""
     )
 
-    pkgs <- unique(c(additional_pkgs, docker_pkgs,
-                     vetiver_model$metadata$required_pkgs))
-    pkgs <- setdiff(pkgs, drop_pkgs)
+    pkgs <- c(additional_pkgs, vetiver_model$metadata$required_pkgs)
+    pkgs <- vetiver_required_pkgs(pkgs)
     lockfile_pkgs <-
         renv$snapshot(
             project = path,
@@ -76,6 +82,7 @@ vetiver_write_docker <- function(vetiver_model,
             prompt = FALSE,
             force = TRUE
         )
+
     plumber_file <- fs::path_rel(plumber_file)
     sys_reqs <- glue_sys_reqs(names(lockfile_pkgs$Packages))
     copy_renv <- glue("COPY {lockfile} renv.lock")
@@ -89,7 +96,7 @@ vetiver_write_docker <- function(vetiver_model,
     ret <- compact(list(
         "# Generated by the vetiver package; edit with care\n",
         ## https://github.com/rstudio/plumber/blob/main/Dockerfile:
-        from_r_version,
+        base_image,
         rspm_env,
         sys_reqs,
         "",
@@ -107,6 +114,12 @@ vetiver_write_docker <- function(vetiver_model,
 docker_pkgs <- c("pins", "plumber", "rapidoc", "vetiver", "renv")
 drop_pkgs <- "stats"
 
+vetiver_required_pkgs <- function(pkgs) {
+    pkgs <- c(docker_pkgs, pkgs)
+    pkgs <- setdiff(pkgs, drop_pkgs)
+    sort(unique(pkgs))
+}
+
 glue_sys_reqs <- function(pkgs) {
     rlang::check_installed(c("curl", "jsonlite"))
     rspm <- Sys.getenv("RSPM_ROOT", DEFAULT_RSPM)
@@ -144,7 +157,7 @@ glue_sys_reqs <- function(pkgs) {
 #' @inheritParams vetiver_write_plumber
 #' @inheritParams vetiver_deploy_rsconnect
 #' @param path A path to write the Plumber file, Dockerfile, and lockfile,
-#' capturing the model's dependencies. Defaults to the working directory.
+#' capturing the model's dependencies.
 #' @param docker_args A list of optional arguments passed to
 #' [vetiver_write_docker()] such as the `lockfile` name or whether to use
 #' `rspm`. Do not pass `additional_pkgs` here, as this function uses
