@@ -27,18 +27,19 @@ test_that("can pin an xgboost model", {
         pinned,
         list(
             model = bundle::bundle(cars_xgb),
-            prototype = vctrs::vec_slice(tibble::as_tibble(mtcars[,2:11]), 0),
-            required_pkgs = c("xgboost")
+            prototype = vctrs::vec_slice(tibble::as_tibble(mtcars[,2:11]), 0)
         )
     )
+    expect_equal(
+        pin_meta(b, "cars2")$user$required_pkgs,
+        "xgboost"
+    )
 })
 
 test_that("default endpoint for xgboost", {
     p <- pr() %>% vetiver_api(v)
     p_routes <- p$routes[-1]
-    expect_equal(names(p_routes), c("ping", "predict"))
-    expect_equal(map_chr(p_routes, "verbs"),
-                 c(ping = "GET", predict = "POST"))
+    expect_api_routes(p_routes)
 })
 
 test_that("default OpenAPI spec", {
